@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 **************************************************************************** */
 #include "version.h"
@@ -24,31 +24,43 @@
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
+#include <klocale.h>
+#include <kglobal.h>
 
 
 static const char description[] =
 	I18N_NOOP("Tactical one or two player game");
 
+// A hack to circumvent tricky i18n issue, not used later on in the code.
+// Both context and contents must be exactly the same as for the entry in
+// kdelibs/kdeui/ui_standards.rc
+static const char dummy[] = I18N_NOOP2("Menu title", "&Move");
 
 int main(int argc, char *argv[])
 {
-    KAboutData aboutData( "kjumpingcube", I18N_NOOP("KJumpingCube"),
-                          KJC_VERSION, description, KAboutData::License_GPL,
-                          "(c) 1998-2000, Matthias Kiefer");
-    aboutData.addAuthor("Matthias Kiefer",0, "matthias.kiefer@gmx.de");
-    aboutData.addAuthor("Benjamin Meyer",I18N_NOOP("Various improvements"), "ben+kjumpingcube@meyerhome.net");
+    KAboutData aboutData( "kjumpingcube", 0, ki18n("KJumpingCube"),
+                          KJC_VERSION, ki18n(description), KAboutData::License_GPL,
+                          ki18n("(c) 1998-2000, Matthias Kiefer"), KLocalizedString(),
+                          "http://games.kde.org/kjumpingcube" );
+    aboutData.addAuthor(ki18n("Matthias Kiefer"),KLocalizedString(), "matthias.kiefer@gmx.de");
+    aboutData.addAuthor(ki18n("Benjamin Meyer"),ki18n("Various improvements"), "ben+kjumpingcube@meyerhome.net");
+    aboutData.addCredit(ki18n("Ian Wadham"),
+                      ki18n("Upgrade to KDE4 and SVG artwork support."),
+                      "ianw2@optusnet.com.au");
+    aboutData.addCredit(ki18n("Eugene Trounev"),
+                      ki18n("Graphics for KDE4.0 version."),
+                      "irs_me@hotmail.com");
     KCmdLineArgs::init( argc, argv, &aboutData );
 
-    KApplication app;
-    KGlobal::locale()->insertCatalogue("libkdegames");
+    KApplication application;
+    KGlobal::locale()->insertCatalog("libkdegames");
 
     // All session management is handled in the RESTORE macro
-	if (app.isRestored())
+	if (application.isSessionRestored())
         RESTORE(KJumpingCube)
     else {
 		KJumpingCube *kjumpingcube = new KJumpingCube;
-		app.setMainWidget(kjumpingcube);
 		kjumpingcube->show();
 	}
-   return app.exec();
+   return application.exec();
 }
