@@ -28,26 +28,21 @@
 #define P_GRANDF_7
 
 #include "dealer.h"
-#include "card.h"
-#include <qpushbutton.h>
 
-class KAction;
 class Pile;
-class Deck;
-class KMainWindow;
 
-class Grandf : public Dealer {
+class Grandf : public DealerScene
+{
+    friend class GrandfSolver;
     Q_OBJECT
 
 public:
-    Grandf( KMainWindow* parent=0, const char* name=0);
+    Grandf( );
 
 public slots:
     void redeal();
     void deal();
     virtual void restart();
-    virtual bool isGameLost() const;
-
 
 protected:
     void collect();
@@ -59,7 +54,6 @@ protected:
 private:
     Pile* store[7];
     Pile* target[4];
-    Deck *deck;
     int numberOfDeals;
 
 };
