@@ -26,20 +26,20 @@
 #include "dealer.h"
 
 
-class Idiot: public Dealer
+class Idiot: public DealerScene
 {
+    friend class IdiotSolver;
+
     Q_OBJECT
 
 public:
 
-    Idiot( KMainWindow* parent = 0, const char* name = 0 );
-
+    Idiot( );
     virtual bool  isGameWon() const;
 
 protected:
     virtual bool  cardClicked(Card *);
     virtual bool  cardDblClicked(Card *);
-    virtual void  getHints();
     virtual Card *demoNewCards();
     virtual bool  startAutoDrop()  { return false; }
 
@@ -49,11 +49,10 @@ public slots:
     void         deal();
 
 private:
-    bool canMoveAway(Card *c);
+    bool canMoveAway(Card *c) const;
 
     Pile  *m_play[ 4 ];
     Pile  *m_away;
-    Deck  *m_deck;
 };
 
 #endif
