@@ -1,3 +1,16 @@
+/*
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation.
+ *
+ * This file is provided AS IS with no warranties of any kind.  The author
+ * shall have no liability with respect to the infringement of copyrights,
+ * trade secrets or any patents by this file or any part thereof.  In no
+ * event will the author be liable for any lost revenue or profits or
+ * other special, indirect and consequential damages.
+*/
 #include "pile.h"
 #include <kdebug.h>
 
@@ -5,9 +18,9 @@ bool Pile::add_klondikeTarget( const CardList& c2 ) const
 {
     Card *newone = c2.first();
     if (isEmpty())
-        return (newone->value() == Card::Ace);
+        return (newone->rank() == Card::Ace);
 
-    return (newone->value() == top()->value() + 1)
+    return (newone->rank() == top()->rank() + 1)
           && (top()->suit() == newone->suit());
 }
 
@@ -15,10 +28,10 @@ bool Pile::add_klondikeStore(  const CardList& c2 ) const
 {
     Card *newone = c2.first();
     if (isEmpty()) {
-        return (newone->value() == Card::King);
+        return (newone->rank() == Card::King);
     }
 
-    return (newone->value() == top()->value() - 1)
+    return (newone->rank() == top()->rank() - 1)
         && (top()->isRed() != newone->isRed());
 }
 
@@ -28,7 +41,7 @@ bool Pile::add_gypsyStore( const CardList& c2) const
     if (isEmpty())
         return true;
 
-    return (newone->value() == top()->value() - 1)
+    return (newone->rank() == top()->rank() - 1)
              && (top()->isRed() != newone->isRed());
 }
 
@@ -53,10 +66,10 @@ bool Pile::remove_freecellStore( const Card *c) const
     {
         c = at(index++);
 
-        if (!((c->value() == (before->value()-1))
+        if (!((c->rank() == (before->rank()-1))
               && (c->isRed() != before->isRed())))
         {
-            kdDebug(11111) << c->name() << " - " << before->name() << endl;
+            kDebug(11111) << c->rank() << " " << c->suit() << " - " << before->rank() << " " << before->suit();
             return false;
         }
         if (c == top())
