@@ -26,33 +26,33 @@
 class SpiderPile : public Pile
 {
 public:
-    SpiderPile(int _index, Dealer* parent = 0) : Pile(_index, parent) {}
+    explicit SpiderPile(int _index, DealerScene* parent = 0) : Pile(_index, parent) {}
     virtual void moveCards(CardList &c, Pile *to);
     CardList getRun();
 };
 
-class Spider : public Dealer
+class Spider : public DealerScene
 {
+    friend class SpiderSolver;
+
     Q_OBJECT
 
 public:
-    Spider(int suits, KMainWindow *parent=0, const char *name=0);
+    Spider(int suits);
     void deal();
     void dealRow();
-    void checkPileDeck(Pile *to);
+    bool checkPileDeck(Pile *to, bool checkForDemo = true);
     virtual void restart();
-    virtual bool isGameLost() const;
 
 public slots:
     void deckClicked(Card *c);
+    void cardStoped(Card *c);
 
 protected:
     virtual bool checkRemove(int /*checkIndex*/, const Pile *p, const Card *c) const;
     virtual bool checkAdd(int /*checkIndex*/, const Pile *c1, const CardList &c2) const;
     virtual QString getGameState() const;
     virtual void setGameState(const QString &stream);
-    virtual void getHints();
-    virtual MoveHint *chooseHint();
     virtual Card *demoNewCards();
 
 private:
@@ -63,7 +63,6 @@ private:
     int m_leg;
     Pile *redeals[5];
     int m_redeal;
-    Deck *deck;
 };
 
 #endif
