@@ -20,18 +20,18 @@
 #ifndef KEXTHIGHSCORE_GUI_H
 #define KEXTHIGHSCORE_GUI_H
 
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qvbox.h>
-#include <qtabwidget.h>
-
-#include <klistview.h>
-#include <klineedit.h>
-#include <kpushbutton.h>
-#include <kdialogbase.h>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLineEdit>
+#include <QtGui/QTreeWidget>
+#include <kpagedialog.h>
+#include <QtCore/QList>
 
 #include "kexthighscore.h"
 
+class QTabWidget;
+class KLineEdit;
+class KPushButton;
+class KUrlLabel;
 
 namespace KExtHighscore
 {
@@ -42,20 +42,16 @@ class Score;
 class AdditionalTab;
 
 //-----------------------------------------------------------------------------
-class ShowItem : public KListViewItem
+class ShowItem : public QTreeWidgetItem
 {
  public:
-    ShowItem(QListView *, bool highlight);
-
- protected:
-    virtual void paintCell(QPainter *, const QColorGroup &, int column,
-						   int width, int align);
+    ShowItem(QTreeWidget *, bool highlight);
 
  private:
     bool _highlight;
 };
 
-class ScoresList : public KListView
+class ScoresList : public QTreeWidget
 {
  Q_OBJECT
  public:
@@ -64,12 +60,12 @@ class ScoresList : public KListView
     void addHeader(const ItemArray &);
 
  protected:
-    QListViewItem *addLine(const ItemArray &, uint index, bool highlight);
+    QTreeWidgetItem *addLine(const ItemArray &, uint index, bool highlight);
     virtual QString itemText(const ItemContainer &, uint row) const = 0;
 
  private:
     virtual void addLineItem(const ItemArray &, uint index,
-                             QListViewItem *item);
+                             QTreeWidgetItem *item);
 };
 
 //-----------------------------------------------------------------------------
@@ -77,7 +73,7 @@ class HighscoresList : public ScoresList
 {
  Q_OBJECT
  public:
-    HighscoresList(QWidget *parent);
+    explicit HighscoresList(QWidget *parent);
 
     void load(const ItemArray &, int highlight);
 
@@ -89,7 +85,7 @@ class HighscoresWidget : public QWidget
 {
  Q_OBJECT
  public:
-    HighscoresWidget(QWidget *parent);
+    explicit HighscoresWidget(QWidget *parent);
 
     void load(int rank);
 
@@ -100,17 +96,17 @@ class HighscoresWidget : public QWidget
     void changeTab(int i);
 
  private slots:
-    void showURL(const QString &) const;
-    void tabChanged() { emit tabChanged(_tw->currentPageIndex()); }
+    void showURL(const QString &);
+    void tabChanged() { emit tabChanged(_tw->currentIndex()); }
 
  private:
     QTabWidget     *_tw;
     HighscoresList *_scoresList, *_playersList;
-    KURLLabel      *_scoresUrl, *_playersUrl;
+    KUrlLabel      *_scoresUrl, *_playersUrl;
     AdditionalTab  *_statsTab, *_histoTab;
 };
 
-class HighscoresDialog : public KDialogBase
+class HighscoresDialog : public KPageDialog
 {
  Q_OBJECT
  public:
@@ -120,12 +116,12 @@ class HighscoresDialog : public KDialogBase
     void slotUser1();
     void slotUser2();
     void tabChanged(int i) { _tab = i; }
-    void createPage(QWidget *);
+    void highscorePageChanged(KPageWidgetItem *newpage, KPageWidgetItem *before);
 
  private:
     int _rank, _tab;
     QWidget *_current;
-    QValueVector<HighscoresWidget *> _widgets;
+    QList<KPageWidgetItem*> _pages;
 };
 
 //-----------------------------------------------------------------------------
@@ -133,36 +129,36 @@ class LastMultipleScoresList : public ScoresList
 {
     Q_OBJECT
 public:
-    LastMultipleScoresList(const QValueVector<Score> &, QWidget *parent);
+    LastMultipleScoresList(const QVector<Score> &, QWidget *parent);
 
 private:
-    void addLineItem(const ItemArray &, uint index, QListViewItem *line);
+    void addLineItem(const ItemArray &, uint index, QTreeWidgetItem *line);
     QString itemText(const ItemContainer &, uint row) const;
 
 private:
-    const QValueVector<Score> &_scores;
+    const QVector<Score> &_scores;
 };
 
 class TotalMultipleScoresList : public ScoresList
 {
     Q_OBJECT
 public:
-    TotalMultipleScoresList(const QValueVector<Score> &, QWidget *parent);
+    TotalMultipleScoresList(const QVector<Score> &, QWidget *parent);
 
 private:
-    void addLineItem(const ItemArray &, uint index, QListViewItem *line);
+    void addLineItem(const ItemArray &, uint index, QTreeWidgetItem *line);
     QString itemText(const ItemContainer &, uint row) const;
 
 private:
-    const QValueVector<Score> &_scores;
+    const QVector<Score> &_scores;
 };
 
 //-----------------------------------------------------------------------------
-class ConfigDialog : public KDialogBase
+class ConfigDialog : public KDialog
 {
  Q_OBJECT
  public:
-    ConfigDialog(QWidget *parent);
+    explicit ConfigDialog(QWidget *parent);
 
     bool hasBeenSaved() const { return _saved; }
 
@@ -185,11 +181,11 @@ class ConfigDialog : public KDialogBase
 };
 
 //-----------------------------------------------------------------------------
-class AskNameDialog : public KDialogBase
+class AskNameDialog : public KDialog
 {
  Q_OBJECT
  public:
-    AskNameDialog(QWidget *parent);
+    explicit AskNameDialog(QWidget *parent);
 
     QString name() const { return _edit->text(); }
     bool dontAskAgain() const { return _checkbox->isChecked(); }
