@@ -1,7 +1,7 @@
 /*
     This file is part of the KDE games library
     Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
-    Copyright (C) 2001 Martin Heni (martin@heni-online.de)
+    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "kgamedialogconfig.h"
@@ -24,20 +24,19 @@
 #include "kplayer.h"
 #include "kgamechat.h"
 #include "kgameconnectdialog.h"
+#include "kgameproperty.h"
 
+#include <klistwidget.h>
 #include <klocale.h>
 #include <knuminput.h>
 #include <kdialog.h>
-#include <klistbox.h>
 #include <kmessagebox.h>
 
-#include <qlayout.h>
-#include <qhgroupbox.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qvbox.h>
-#include <qptrdict.h>
+#include <QLayout>
+#include <QLabel>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QGroupBox>
 
 #include "kgamedialogconfig.moc"
 
@@ -57,14 +56,15 @@ public:
 	KPlayer* mOwner;
 };
 
-KGameDialogConfig::KGameDialogConfig(QWidget* parent) : QWidget(parent)
+KGameDialogConfig::KGameDialogConfig(QWidget* parent) 
+    : QWidget( parent ),
+      d( new KGameDialogConfigPrivate )
 {
- d = new KGameDialogConfigPrivate;
 }
 
 KGameDialogConfig::~KGameDialogConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  delete d;
 }
 
@@ -105,7 +105,7 @@ public:
 	}
 
 	// QPushButton* mInitConnection;
-	QHGroupBox* mInitConnection;
+	QGroupBox* mInitConnection;
 	QLabel* mNetworkLabel;
 	QPushButton *mDisconnectButton;
 
@@ -119,12 +119,16 @@ public:
 KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
 		: KGameDialogConfig(parent)
 {
-// kdDebug(11001) << k_funcinfo << ": this=" << this << endl;
+// kDebug(11001) << ": this=" << this;
  d = new KGameDialogNetworkConfigPrivate();
 
- QVBoxLayout* topLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint(), "toplayout");
+ QVBoxLayout* topLayout = new QVBoxLayout(this);
+ topLayout->setMargin( KDialog::marginHint() );
+ topLayout->setSpacing( KDialog::spacingHint() );
 
- QHBoxLayout *hb = new QHBoxLayout(topLayout, KDialog::spacingHint());
+ QHBoxLayout *hb = new QHBoxLayout;
+ hb->setSpacing( KDialog::spacingHint() );
+ topLayout->addLayout(hb);
 
  d->mNetworkLabel = new QLabel(this);
  hb->addWidget(d->mNetworkLabel);
@@ -133,10 +137,12 @@ KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
  connect(d->mDisconnectButton, SIGNAL(clicked()), this, SLOT(slotExitConnection()));
  hb->addWidget(d->mDisconnectButton);
 
- d->mInitConnection = new QHGroupBox(i18n("Network Configuration"), this);
+ d->mInitConnection = new QGroupBox(i18n("Network Configuration"), this);
+ QHBoxLayout* gboxLay = new QHBoxLayout(d->mInitConnection);
  topLayout->addWidget(d->mInitConnection);
 
  d->mConnect = new KGameConnectWidget(d->mInitConnection);
+ gboxLay->addWidget(d->mConnect);
  connect(d->mConnect, SIGNAL(signalNetworkSetup()), this, SLOT(slotInitConnection()));
  connect(d->mConnect, SIGNAL(signalServerTypeChanged(int)),
          this, SIGNAL(signalServerTypeChanged(int)));
@@ -148,20 +154,20 @@ KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
 
 KGameDialogNetworkConfig::~KGameDialogNetworkConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  delete d;
 }
 
 void KGameDialogNetworkConfig::slotExitConnection()
 {
- kdDebug(11001) << k_funcinfo << " !!!!!!!!!!!!!!!!!!!!!!!" << endl;
+ kDebug(11001) << " !!!!!!!!!!!!!!!!!!!!!!!";
   if (game()) game()->disconnect();
   setConnected(false,false);
 }
 
 void KGameDialogNetworkConfig::slotInitConnection()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  bool connected = false;
  bool master = true;
  unsigned short int port = d->mConnect->port();
@@ -189,7 +195,7 @@ void KGameDialogNetworkConfig::slotInitConnection()
 
 void KGameDialogNetworkConfig::slotConnectionBroken()
 {
-  kdDebug(11001) << k_funcinfo << endl;
+  kDebug(11001) ;
   setConnected(false,false);
   KMessageBox::error(this, i18n("Cannot connect to the network"));
 }
@@ -244,7 +250,7 @@ void KGameDialogNetworkConfig::setDiscoveryInfo(const QString& type, const QStri
 {
  d->mConnect->setType(type);
  d->mConnect->setName(name);
-} 
+}
 
 /////////////////////////// KGameDialogGeneralConfig /////////////////////////
 class KGameDialogGeneralConfigPrivate
@@ -264,14 +270,16 @@ public:
 KGameDialogGeneralConfig::KGameDialogGeneralConfig(QWidget* parent, bool initializeGUI)
 		: KGameDialogConfig(parent)
 {
-// kdDebug(11001) << k_funcinfo << ": this=" << this << endl;
+// kDebug(11001) << ": this=" << this;
  d = new KGameDialogGeneralConfigPrivate;
 
  if (initializeGUI) {
-	d->mTopLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
-	d->mTopLayout->setAutoAdd(true);
+	d->mTopLayout = new QVBoxLayout(this);
+	d->mTopLayout->setMargin( KDialog::marginHint() );
+	d->mTopLayout->setSpacing( KDialog::spacingHint() );
 
 	QWidget* nameWidget = new QWidget(this);
+        d->mTopLayout->addWidget(nameWidget);
 	QHBoxLayout* l = new QHBoxLayout(nameWidget);
 	QLabel* nameLabel = new QLabel(i18n("Your name:"), nameWidget);
 	l->addWidget(nameLabel);
@@ -282,7 +290,7 @@ KGameDialogGeneralConfig::KGameDialogGeneralConfig(QWidget* parent, bool initial
 
 KGameDialogGeneralConfig::~KGameDialogGeneralConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  delete d;
 }
 
@@ -295,7 +303,7 @@ void KGameDialogGeneralConfig::setPlayerName(const QString& name)
 
 QString KGameDialogGeneralConfig::playerName() const
 {
- return d->mName ? d->mName->text() : QString::null;
+ return d->mName ? d->mName->text() : QString();
 }
 
 void KGameDialogGeneralConfig::setOwner(KPlayer* p)
@@ -393,14 +401,18 @@ KGameDialogMsgServerConfig::KGameDialogMsgServerConfig(QWidget* parent)
 {
  d = new KGameDialogMsgServerConfigPrivate;
 
- QVBoxLayout* topLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
- d->senderLayout = new QVBoxLayout(topLayout);
- d->localLayout = new QHBoxLayout(topLayout);
+ QVBoxLayout* topLayout = new QVBoxLayout(this);
+ topLayout->setMargin( KDialog::marginHint() );
+ topLayout->setSpacing( KDialog::spacingHint() );
+ d->senderLayout = new QVBoxLayout;
+ d->localLayout = new QHBoxLayout;
+ topLayout->addLayout( d->senderLayout );
+ topLayout->addLayout( d->localLayout );
 }
 
 KGameDialogMsgServerConfig::~KGameDialogMsgServerConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  delete d;
 }
 
@@ -422,23 +434,25 @@ void KGameDialogMsgServerConfig::setKGame(KGame* g)
 void KGameDialogMsgServerConfig::slotChangeMaxClients()
 {
  if (!game()) {
-	kdError(11001) << k_funcinfo << ": no valid game object available!" << endl;
+	kError(11001) << ": no valid game object available!";
 	return;
  }
  if (!game()->isAdmin()) {
-	kdError(11001) << k_funcinfo << ": only ADMIN is allowed to call this!" << endl;
+	kError(11001) << ": only ADMIN is allowed to call this!";
 	return;
  }
  int max;
 // edit->setText(QString::number()); // current max clients! //TODO
 
  QDialog* dialog = new QDialog();
- dialog->setCaption(i18n("Maximal Number of Clients"));
- QHBoxLayout* l = new QHBoxLayout(dialog, KDialog::marginHint(), KDialog::spacingHint());
- l->setAutoAdd(true);
+ dialog->setWindowTitle(i18n("Maximal Number of Clients"));
+ QHBoxLayout* l = new QHBoxLayout(dialog);
+ l->setMargin( KDialog::marginHint() );
+ l->setSpacing( KDialog::spacingHint() );
 
- (void) new QLabel(i18n("Maximal number of clients (-1 = infinite):"), dialog);
+ l->addWidget(new QLabel(i18n("Maximal number of clients (-1 = infinite):"), dialog));
  QLineEdit* edit = new QLineEdit(dialog);//TODO: use KIntNumInput
+ l->addWidget(edit);
 // edit->setText(QString::number(max)); // current max clients! //TODO
  if (dialog->exec() == QDialog::Accepted) {
 	bool ok;
@@ -457,20 +471,20 @@ void KGameDialogMsgServerConfig::slotRemoveClient()
 void KGameDialogMsgServerConfig::slotChangeAdmin()
 {
  if (!game()) {
-	kdError(11001) << k_funcinfo << ": no valid game object available!" << endl;
+	kError(11001) << ": no valid game object available!";
 	return;
  }
  if (!admin()) {
-	kdError(11001) << k_funcinfo << ": only ADMIN is allowed to call this!" << endl;
+	kError(11001) << ": only ADMIN is allowed to call this!";
 	return;
  }
  //TODO
- Q_UINT32 newAdmin = 0;
+ quint32 newAdmin = 0;
 // newAdmin = ;
  game()->electAdmin(newAdmin);
 }
 
-void KGameDialogMsgServerConfig::removeClient(Q_UINT32 /*id*/)
+void KGameDialogMsgServerConfig::removeClient(quint32 /*id*/)
 {
 //TODO
 }
@@ -520,7 +534,7 @@ void KGameDialogMsgServerConfig::setHasMsgServer(bool has)
  if (!has) {
 	// delete all inputs
 	if (!d->noMaster) {
-		d->noMaster = new QLabel(i18n("You don't own the message server"), this);
+		d->noMaster = new QLabel(i18n("You do not own the message server"), this);
 		d->localLayout->addWidget(d->noMaster);
 	}
 	return;
@@ -551,15 +565,19 @@ KGameDialogChatConfig::KGameDialogChatConfig(int chatMsgId, QWidget* parent)
 		: KGameDialogConfig(parent)
 {
  d = new KGameDialogChatConfigPrivate;
- QVBoxLayout* topLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
- topLayout->setAutoAdd(true);
- QHGroupBox* b = new QHGroupBox(i18n("Chat"), this);
+ QVBoxLayout* topLayout = new QVBoxLayout(this);
+ topLayout->setMargin( KDialog::marginHint() );
+ topLayout->setSpacing( KDialog::spacingHint() );
+ QGroupBox* b = new QGroupBox(i18n("Chat"), this);
+ topLayout->addWidget(b);
+ QHBoxLayout* gboxLay = new QHBoxLayout(b);
  d->mChat = new KGameChat(0, chatMsgId, b);
+ gboxLay->addWidget(d->mChat);
 }
 
 KGameDialogChatConfig::~KGameDialogChatConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  delete d;
 }
 
@@ -595,8 +613,8 @@ public:
 		mPlayerBox = 0;
 	}
 
-	QPtrDict<KPlayer> mItem2Player;
-	KListBox* mPlayerBox;
+	QHash<QListWidgetItem*, KPlayer*> mItem2Player;
+	KListWidget* mPlayerBox;
 };
 
 KGameDialogConnectionConfig::KGameDialogConnectionConfig(QWidget* parent)
@@ -604,16 +622,20 @@ KGameDialogConnectionConfig::KGameDialogConnectionConfig(QWidget* parent)
 {
  //TODO: prevent player to ban himself
  d = new KGameDialogConnectionConfigPrivate;
- QVBoxLayout* topLayout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
- topLayout->setAutoAdd(true);
- QHGroupBox* b = new QHGroupBox(i18n("Connected Players"), this);
- d->mPlayerBox = new KListBox(b);
+ QVBoxLayout* topLayout = new QVBoxLayout(this);
+ topLayout->setMargin( KDialog::marginHint() );
+ topLayout->setSpacing( KDialog::spacingHint() );
+ QGroupBox* b = new QGroupBox(i18n("Connected Players"), this);
+ topLayout->addWidget(b);
+ QHBoxLayout* gboxLay = new QHBoxLayout(b);
+ d->mPlayerBox = new KListWidget(b);
+ gboxLay->addWidget(d->mPlayerBox);
  setMinimumHeight(100);
 }
 
 KGameDialogConnectionConfig::~KGameDialogConnectionConfig()
 {
- kdDebug(11001) << k_funcinfo << endl;
+ kDebug(11001) ;
  // d->mIem2Player.clear();
  delete d;
 }
@@ -632,9 +654,9 @@ void KGameDialogConnectionConfig::setKGame(KGame* g)
 	connect(game(), SIGNAL(signalPlayerLeftGame(KPlayer*)),
 			this, SLOT(slotPlayerLeftGame(KPlayer*)));
 
-	KGame::KGamePlayerList l = *game()->playerList();
-	for (KPlayer* p = l.first(); p; p = l.next()) {
-		slotPlayerJoinedGame(p);
+  for ( QList<KPlayer*>::const_iterator it = game()->playerList()->begin(); it!=game()->playerList()->end();it++ )
+  {
+		slotPlayerJoinedGame(*it);
 	}
  }
 }
@@ -650,41 +672,41 @@ void KGameDialogConnectionConfig::setAdmin(bool a)
 	return;
  }
  if (admin()) {
-	disconnect(game(), SIGNAL(executed(QListBoxItem*)), this, 0);
+	disconnect(game(), SIGNAL(executed(QListWidgetItem*)), this, 0);
  }
  KGameDialogConfig::setAdmin(a);
  if (admin()) {
-	connect(d->mPlayerBox, SIGNAL(executed(QListBoxItem*)), this,
-			SLOT(slotKickPlayerOut(QListBoxItem*)));
+	connect(d->mPlayerBox, SIGNAL(executed(QListWidgetItem*)), this,
+			SLOT(slotKickPlayerOut(QListWidgetItem*)));
  }
 }
 
-QListBoxItem* KGameDialogConnectionConfig::item(KPlayer* p) const
+QListWidgetItem* KGameDialogConnectionConfig::item(KPlayer* p) const
 {
- QPtrDictIterator<KPlayer> it(d->mItem2Player);
- while (it.current()) {
-	if (it.current() == p) {
-		return (QListBoxItem*)it.currentKey();
-	}
-	++it;
+ QHash<QListWidgetItem*, KPlayer*>::const_iterator it, itEnd;
+ it = d->mItem2Player.constBegin();
+ itEnd = d->mItem2Player.constEnd();
+ for ( ; it != itEnd; ++it ) {
+	if (it.value() == p) return it.key();
  }
  return 0;
 }
 
 void KGameDialogConnectionConfig::slotClearPlayers()
 {
- QPtrDictIterator<KPlayer> it(d->mItem2Player);
- while (it.current()) {
-	slotPlayerLeftGame(it.current());
-	++it;
+ QHash<QListWidgetItem*, KPlayer*>::const_iterator it, itEnd;
+ it = d->mItem2Player.constBegin();
+ itEnd = d->mItem2Player.constEnd();
+ for ( ; it != itEnd; ++it ) {
+	slotPlayerLeftGame(it.value());
  }
 
  if (d->mItem2Player.count() > 0) {
-	kdWarning(11001) << k_funcinfo << ": itemList wasn't cleared properly" << endl;
+	kWarning(11001) << ": itemList wasn't cleared properly";
 	d->mItem2Player.clear();
  }
  if (d->mPlayerBox->count() > 0) {
-	kdWarning(11001) << k_funcinfo << ": listBox wasn't cleared properly" << endl;
+	kWarning(11001) << ": listBox wasn't cleared properly";
 	d->mPlayerBox->clear();
  }
 
@@ -693,16 +715,21 @@ void KGameDialogConnectionConfig::slotClearPlayers()
 void KGameDialogConnectionConfig::slotPlayerJoinedGame(KPlayer* p)
 {
  if (!p) {
-	kdError(11001) << k_funcinfo << ": Cannot add NULL player" << endl;
+	kError(11001) << ": Cannot add NULL player";
+        return;
  }
- if (d->mItem2Player[p]) {
-	kdError(11001) << k_funcinfo << ": attempt to double add player" << endl;
+ bool playerFound = false;
+ QHash<QListWidgetItem*, KPlayer*>::const_iterator it, itEnd;
+ it = d->mItem2Player.constBegin();
+ itEnd = d->mItem2Player.constEnd();
+ for ( ; !playerFound && it != itEnd; ++it ) playerFound = it.value() == p;
+ if (playerFound) {
+	kError(11001) << ": attempt to double add player";
 	return;
  }
- kdDebug(11001) << k_funcinfo << ": add player " << p->id() << endl;
- QListBoxText* t = new QListBoxText(p->name());
+ kDebug(11001) << ": add player" << p->id();
+ QListWidgetItem* t = new QListWidgetItem(p->name(), d->mPlayerBox);
  d->mItem2Player.insert(t, p);
- d->mPlayerBox->insertItem(t);
 
  connect(p, SIGNAL(signalPropertyChanged(KGamePropertyBase*, KPlayer*)),
 		this, SLOT(slotPropertyChanged(KGamePropertyBase*, KPlayer*)));
@@ -714,58 +741,53 @@ void KGameDialogConnectionConfig::slotPlayerLeftGame(KPlayer* p)
  // disconnect first
  this->disconnect(p);
  if (!item(p)) {
-	kdError(11001) << k_funcinfo << ": cannot find " << p->id()
-			<< " in list" << endl;
+	kError(11001) << ": cannot find" << p->id()
+			<< "in list";
 	return;
  }
- d->mPlayerBox->removeItem(d->mPlayerBox->index(item(p)));
+ d->mPlayerBox->takeItem(d->mPlayerBox->row(item(p)));
 
 }
 
-void KGameDialogConnectionConfig::slotKickPlayerOut(QListBoxItem* item)
+void KGameDialogConnectionConfig::slotKickPlayerOut(QListWidgetItem* item)
 {
- kdDebug(11001) << "kick player out" << endl;
+ kDebug(11001) << "kick player out";
  KPlayer* p = d->mItem2Player[item];
  if (!p) {
-	kdError(11001) << "invalid item selected - no player found" << endl;
+	kError(11001) << "invalid item selected - no player found";
 	return;
  }
  if (!game()) {
-	kdWarning(11001) << "no game set" << endl;
+	kWarning(11001) << "no game set";
 	return;
  }
  if (!admin()) {
-	kdDebug(11001) << "Only the ADMIN can kick players" << endl;
+	kDebug(11001) << "Only the ADMIN can kick players";
 	return;
  }
  if (p == owner()) { // you wanna ban the ADMIN ??
-	kdDebug(11001) << "you cannot kick the ADMIN" << endl;
+	kDebug(11001) << "you cannot kick the ADMIN";
 	return;
  }
 
- if (KMessageBox::questionYesNo(this, i18n("Do you want to ban player \"%1\" from the game?").arg(
-		p->name())) == KMessageBox::Yes) {
-	kdDebug(11001) << "will remove player " << p << endl;
+ if (KMessageBox::questionYesNo(this, i18n("Do you want to ban player \"%1\" from the game?",
+		p->name()), QString(), KGuiItem (i18n("Ban Player")), KGuiItem (i18n("Do Not Ban"))) == KMessageBox::Yes) {
+	kDebug(11001) << "will remove player" << p;
 	game()->removePlayer(p);
 //	d->mPlayerBox->removeItem(d->mPlayerBox->index(item)); // should be done by signalPlayerLeftGame
  } else {
-	kdDebug(11001) << "will NOT remove player " << p << endl;
+	kDebug(11001) << "will NOT remove player" << p;
  }
 }
 
 void KGameDialogConnectionConfig::slotPropertyChanged(KGamePropertyBase* prop, KPlayer* player)
 {
  if(prop->id() == KGamePropertyBase::IdName) {
-	QListBoxText* old = 0;
-	QPtrDictIterator<KPlayer> it(d->mItem2Player);
-	while (it.current() && !old) {
-		if (it.current() == player) {
-			old = (QListBoxText*)it.currentKey();
-		}
-		++it;
-	}
-	QListBoxText* t = new QListBoxText(player->name());
-	d->mPlayerBox->changeItem(t, d->mPlayerBox->index(old));
+	QListWidgetItem* old = item(player);
+	QListWidgetItem* t = new QListWidgetItem(player->name());
+	int row = d->mPlayerBox->row(old);
+	d->mPlayerBox->takeItem( row );
+	d->mPlayerBox->insertItem(row, t);
 	d->mItem2Player.remove(old);
 	d->mItem2Player.insert(t, player);
  }
