@@ -1,7 +1,7 @@
 /*
     This file is part of the KDE games library
     Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
-    Copyright (C) 2001 Martin Heni (martin@heni-online.de)
+    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -21,17 +21,20 @@
 #ifndef __KGAMEPROPERTY_H_
 #define __KGAMEPROPERTY_H_
 
-#include <qdatastream.h>
+#include <QtCore/QDataStream>
 
 #include <kdebug.h>
 #include <typeinfo>
-#include <kdemacros.h>
+#include <libkdegames_export.h>
+
 class KGame;
 class KPlayer;
 class KGamePropertyHandler;
 using namespace std;
 
 /**
+ * \class KGamePropertyBase kgameproperty.h <KGame/KGameProperty>
+ * 
  * @short Base class of KGameProperty
  *
  * The KGamePropertyBase class is the base class of KGameProperty. See
@@ -39,7 +42,7 @@ using namespace std;
  * 
  * @author Andreas Beckermann <b_mann@gmx.de>
  **/
-class KDE_EXPORT KGamePropertyBase
+class KDEGAMES_EXPORT KGamePropertyBase
 {
 public:
 	enum PropertyDataIds  { // these belong to KPlayer/KGame!
@@ -66,7 +69,7 @@ public:
 	};
 
 	/**
-	 * Commands for advanced properties (Q_INT8)
+	 * Commands for advanced properties (qint8)
 	 **/
 	enum PropertyCommandIds 
 	{
@@ -151,8 +154,8 @@ public:
 
 	/**
 	 * Sets this property to emit a signal on value changed.
-	 * As the proerties do not inehrit QObject for optimisation
-	 * this signal is emited via the KPlayer or KGame object
+	 * As the properties do not inherit QObject for optimization
+	 * this signal is emitted via the KPlayer or KGame object
 	 **/
 	void setEmittingSignal(bool p)	{ mFlags.bits.emitsignal=p; }
 
@@ -261,25 +264,25 @@ public:
 	 * @param name if not 0 you can assign a name to this property
 	 *
 	 **/
-	int registerData(int id, KGamePropertyHandler* owner,PropertyPolicy p, QString name=0);
+	int registerData(int id, KGamePropertyHandler* owner,PropertyPolicy p, const QString& name=0);
 
 	/** 
 	 * This is an overloaded member function, provided for convenience.
 	 * It differs from the above function only in what argument(s) it accepts.
 	 **/
-	int registerData(int id, KGamePropertyHandler* owner, QString name=0);
+	int registerData(int id, KGamePropertyHandler* owner, const QString& name=0);
 
 	/** 
 	 * This is an overloaded member function, provided for convenience.
 	 * It differs from the above function only in what argument(s) it accepts.
 	 **/
-	int registerData(int id, KGame* owner, QString name=0);
+        int registerData(int id, KGame* owner, const QString& name=0);
 
 	/** 
 	 * This is an overloaded member function, provided for convenience.
 	 * It differs from the above function only in what argument(s) it accepts.
 	 **/
-	int registerData(int id, KPlayer* owner, QString name=0);
+        int registerData(int id, KPlayer* owner, const QString& name=0);
 
 	/** 
 	 * This is an overloaded member function, provided for convenience.
@@ -287,7 +290,7 @@ public:
 	 * In particular you can use this function to create properties which
 	 * will have an automatic id assigned. The new id is returned.
 	 **/
-	int registerData(KGamePropertyHandler* owner,PropertyPolicy p=PolicyUndefined, QString name=0);
+        int registerData(KGamePropertyHandler* owner,PropertyPolicy p=PolicyUndefined, const QString& name=0);
 
 	void unregisterData();
 
@@ -381,6 +384,8 @@ private:
 };
 
 /**
+ * \class KGameProperty kgameproperty.h <KGame/KGameProperty>
+ * 
  * @short A class for network transparent games
  *
  * Note: The entire API documentation is obsolete!
@@ -546,16 +551,16 @@ private:
  * };
  * QDataStream& operator<<(QDataStream& stream, Card& card)
  * {
- * Q_INT16 type = card.type;
- * Q_INT16 suite = card.suite;
+ * qint16 type = card.type;
+ * qint16 suite = card.suite;
  * s << type;
  * s << suite;
  * return s;
  * }
  * QDataStream& operator>>(QDataStream& stream, Card& card)
  * {
- * Q_INT16 type;
- * Q_INT16 suite;
+ * qint16 type;
+ * qint16 suite;
  * s >> type;
  * s >> suite;
  * card.type = (int)type;
@@ -625,7 +630,7 @@ public:
 				setLocal(v);
 				break;
 			default: // NEVER!
-				kdError(11001) << "Undefined Policy in property " << id() << endl;
+				kError(11001) << "Undefined Policy in property" << id();
 				return;
 		}
 	}
@@ -676,7 +681,7 @@ public:
 			return false;
 		}
 		QByteArray b;
-		QDataStream stream(b, IO_WriteOnly);
+		QDataStream stream(&b, QIODevice::WriteOnly);
 		stream << v;
 		if (!sendProperty(b)) {
 			setLocal(v);
@@ -843,6 +848,6 @@ private:
 typedef KGameProperty<int>   KGamePropertyInt;
 typedef KGameProperty<unsigned int>   KGamePropertyUInt;
 typedef KGameProperty<QString>   KGamePropertyQString;
-typedef KGameProperty<Q_INT8>   KGamePropertyBool;
+typedef KGameProperty<qint8>   KGamePropertyBool;
 
 #endif
