@@ -22,64 +22,60 @@
 */
 
 #include "kmessageio.h"
-#include <qsocket.h>
+#include <QTcpSocket>
 #include <kdebug.h>
 #include <kprocess.h>
-#include <qfile.h>
-
+#include <QFile>
+#include <QDataStream>
 // ----------------------- KMessageIO -------------------------
 
-KMessageIO::KMessageIO (QObject *parent, const char *name)
-  : QObject (parent, name), m_id (0)
+KMessageIO::KMessageIO (QObject *parent)
+  : QObject (parent), m_id (0)
 {}
 
 KMessageIO::~KMessageIO ()
 {}
 
-void KMessageIO::setId (Q_UINT32 id)
+void KMessageIO::setId (quint32 id)
 {
   m_id = id;
 }
 
-Q_UINT32 KMessageIO::id ()
+quint32 KMessageIO::id ()
 {
   return m_id;
 }
 
 // ----------------------KMessageSocket -----------------------
 
-KMessageSocket::KMessageSocket (QString host, Q_UINT16 port, QObject *parent, 
-const char *name)
-  : KMessageIO (parent, name)
+KMessageSocket::KMessageSocket (const QString& host, quint16 port, QObject *parent)
+  : KMessageIO (parent)
 {
-  mSocket = new QSocket ();
+  mSocket = new QTcpSocket ();
   mSocket->connectToHost (host, port);
   initSocket ();
 }
 
-KMessageSocket::KMessageSocket (QHostAddress host, Q_UINT16 port, QObject 
-*parent, const char *name)
-  : KMessageIO (parent, name)
+KMessageSocket::KMessageSocket (QHostAddress host, quint16 port, QObject *parent)
+  : KMessageIO (parent)
 {
-  mSocket = new QSocket ();
+  mSocket = new QTcpSocket ();
   mSocket->connectToHost (host.toString(), port);
   initSocket ();
 }
 
-KMessageSocket::KMessageSocket (QSocket *socket, QObject *parent, const char 
-*name)
-  : KMessageIO (parent, name)
+KMessageSocket::KMessageSocket (QTcpSocket *socket, QObject *parent)
+  : KMessageIO (parent)
 {
   mSocket = socket;
   initSocket ();
 }
 
-KMessageSocket::KMessageSocket (int socketFD, QObject *parent, const char 
-*name)
-  : KMessageIO (parent, name)
+KMessageSocket::KMessageSocket (int socketFD, QObject *parent)
+  : KMessageIO (parent)
 {
-  mSocket = new QSocket ();
-  mSocket->setSocket (socketFD);
+  mSocket = new QTcpSocket ();
+  mSocket->setSocketDescriptor (socketFD);
   initSocket ();
 }
 
@@ -90,14 +86,14 @@ KMessageSocket::~KMessageSocket ()
 
 bool KMessageSocket::isConnected () const
 {
-  return mSocket->state() == QSocket::Connection;
+  return mSocket->state() == QAbstractSocket::ConnectedState;
 }
 
 void KMessageSocket::send (const QByteArray &msg)
 {
   QDataStream str (mSocket);
-  str << Q_UINT8 ('M');  // magic number for begin of message
-  str.writeBytes (msg.data(), msg.size());  // writes the length (as Q_UINT32) and the data
+  str << quint8 ('M');  // magic number for begin of message
+  str.writeBytes (msg.data(), msg.size());  // writes the length (as quint32) and the data
 }
 
 void KMessageSocket::processNewData ()
@@ -121,11 +117,11 @@ void KMessageSocket::processNewData ()
       // Read the magic number first. If something unexpected is found,
       // start over again, ignoring the data that was read up to then.
 
-      Q_UINT8 v;
+      quint8 v;
       str >> v;
       if (v != 'M')
       {
-        kdWarning(11001) << k_funcinfo << ": Received unexpected data, magic number wrong!" << endl;
+        kWarning(11001) << ": Received unexpected data, magic number wrong!";
         continue;
       }
 
@@ -135,14 +131,14 @@ void KMessageSocket::processNewData ()
     else
     {
       // Data not completely read => wait for more
-      if (mSocket->bytesAvailable() < (Q_ULONG) mNextBlockLength)
+      if (mSocket->bytesAvailable() < (qint64) mNextBlockLength)
       {
         isRecursive = false;
         return;
       }
 
-      QByteArray msg (mNextBlockLength);
-      str.readRawBytes (msg.data(), mNextBlockLength);
+      QByteArray msg (mNextBlockLength, 0);
+      str.readRawData (msg.data(), mNextBlockLength);
 
       // send the received message
       emit received (msg);
@@ -157,15 +153,15 @@ void KMessageSocket::processNewData ()
 
 void KMessageSocket::initSocket ()
 {
-  connect (mSocket, SIGNAL (error(int)), SIGNAL (connectionBroken()));
-  connect (mSocket, SIGNAL (connectionClosed()), SIGNAL (connectionBroken()));
-  connect (mSocket, SIGNAL (readyRead()), SLOT (processNewData()));
+  connect (mSocket, SIGNAL (error(QAbstractSocket::SocketError)), this, SIGNAL (connectionBroken()));
+  connect (mSocket, SIGNAL (disconnected()), this, SIGNAL (connectionBroken()));
+  connect (mSocket, SIGNAL (readyRead()), this, SLOT (processNewData()));
   mAwaitingHeader = true;
   mNextBlockLength = 0;
   isRecursive = false;
 }
 
-Q_UINT16 KMessageSocket::peerPort () const
+quint16 KMessageSocket::peerPort () const
 {
   return mSocket->peerPort();
 }
@@ -177,9 +173,8 @@ QString KMessageSocket::peerName () const
 
 // ----------------------KMessageDirect -----------------------
 
-KMessageDirect::KMessageDirect (KMessageDirect *partner, QObject *parent, 
-const char *name)
-  : KMessageIO (parent, name), mPartner (0)
+KMessageDirect::KMessageDirect (KMessageDirect *partner, QObject *parent)
+  : KMessageIO (parent), mPartner (0)
 {
   // 0 as first parameter leaves the object unconnected
   if (!partner)
@@ -188,7 +183,7 @@ const char *name)
   // Check if the other object is already connected
   if (partner && partner->mPartner)
   {
-    kdWarning(11001) << k_funcinfo << ": Object is already connected!" << endl;
+    kWarning(11001) << ": Object is already connected!";
     return;
   }
 
@@ -218,7 +213,7 @@ void KMessageDirect::send (const QByteArray &msg)
   if (mPartner)
     emit mPartner->received (msg);
   else
-    kdError(11001) << k_funcinfo << ": Not yet connected!" << endl;
+    kError(11001) << ": Not yet connected!";
 }
 
 
@@ -226,154 +221,126 @@ void KMessageDirect::send (const QByteArray &msg)
 
 KMessageProcess::~KMessageProcess()
 {
-  kdDebug(11001) << "@@@KMessageProcess::Delete process" << endl;
+  kDebug(11001) << "@@@KMessageProcess::Delete process";
   if (mProcess)
   {
     mProcess->kill();
-    delete mProcess;
+    mProcess->deleteLater();
     mProcess=0;
-    // Remove not send buffers
-    mQueue.setAutoDelete(true);
-    mQueue.clear();
     // Maybe todo: delete mSendBuffer
   }
 }
-KMessageProcess::KMessageProcess(QObject *parent, QString file) : KMessageIO(parent,0)
+KMessageProcess::KMessageProcess(QObject *parent, const QString& file) : KMessageIO(parent)
 {
   // Start process
-  kdDebug(11001) << "@@@KMessageProcess::Start process" << endl;
+  kDebug(11001) << "@@@KMessageProcess::Start process";
   mProcessName=file;
   mProcess=new KProcess;
+  // Need both stdout and stderr as separate channels in the communication
+  mProcess-> setOutputChannelMode(KProcess::SeparateChannels);
   int id=0;
   *mProcess << mProcessName << QString("%1").arg(id);
-  kdDebug(11001) << "@@@KMessageProcess::Init:Id= " << id << endl;
-  kdDebug(11001) << "@@@KMessgeProcess::Init:Processname: " << mProcessName << endl;
-  connect(mProcess, SIGNAL(receivedStdout(KProcess *, char *, int )),
-                        this, SLOT(slotReceivedStdout(KProcess *, char * , int )));
-  connect(mProcess, SIGNAL(receivedStderr(KProcess *, char *, int )),
-                        this, SLOT(slotReceivedStderr(KProcess *, char * , int )));
-  connect(mProcess, SIGNAL(processExited(KProcess *)),
-                        this, SLOT(slotProcessExited(KProcess *)));
-  connect(mProcess, SIGNAL(wroteStdin(KProcess *)),
-                        this, SLOT(slotWroteStdin(KProcess *)));
-  mProcess->start(KProcess::NotifyOnExit,KProcess::All);
+  kDebug(11001) << "@@@KMessageProcess::Init:Id=" << id;
+  kDebug(11001) << "@@@KMessgeProcess::Init:Processname:" << mProcessName;
+  connect(mProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(slotReceivedStdout()));
+  connect(mProcess, SIGNAL(readyReadStandardError()),  this, SLOT(slotReceivedStderr()));
+  connect(mProcess, SIGNAL(finished (int, QProcess::ExitStatus)),
+                        this, SLOT(slotProcessExited(int, QProcess::ExitStatus)));
+  mProcess->start();
   mSendBuffer=0;
   mReceiveCount=0;
   mReceiveBuffer.resize(1024);
 }
 bool KMessageProcess::isConnected() const
 {
-  kdDebug(11001) << "@@@KMessageProcess::Is conencted" << endl;
-  if (!mProcess) return false;
-  return mProcess->isRunning();
+  kDebug(11001) << "@@@KMessageProcess::Is conencted";
+  if (!mProcess)
+     return false;
+  return (mProcess->state() == QProcess::Running);
 }
+
+// Send to process
 void KMessageProcess::send(const QByteArray &msg)
 {
-  kdDebug(11001) << "@@@KMessageProcess:: SEND("<<msg.size()<<") to process" << endl;
+  kDebug(11001) << "@@@KMessageProcess:: SEND("<<msg.size()<<") to process";
   unsigned int size=msg.size()+2*sizeof(long);
 
+  if (mProcess == 0) {
+    kDebug(11001) << "@@@KMessageProcess:: cannot write to stdin, no process available";
+    return;
+  }
+
   char *tmpbuffer=new char[size];
   long *p1=(long *)tmpbuffer;
   long *p2=p1+1;
-  kdDebug(11001)  << "p1="<<p1 << "p2="<< p2 << endl;
+  kDebug(11001)  << "p1="<<p1 << "p2="<< p2;
   memcpy(tmpbuffer+2*sizeof(long),msg.data(),msg.size());
   *p1=0x4242aeae;
   *p2=size;
   
-  QByteArray *buffer=new QByteArray();
-  buffer->assign(tmpbuffer,size);
-  // buffer->duplicate(msg);
-  mQueue.enqueue(buffer);
-  writeToProcess(); 
+  // no need to add it to a queue -> qiodevice is buffered
+  mProcess->write(tmpbuffer,size);
+  delete [] tmpbuffer;
 }
-void KMessageProcess::writeToProcess()
-{
-  // Previous send ok and item in queue
-  if (mSendBuffer || mQueue.isEmpty()) return ;
-  mSendBuffer=mQueue.dequeue();
-  if (!mSendBuffer) return ;
 
-  // write it out to the process
-  //  kdDebug(11001) << " @@@@@@ writeToProcess::SEND to process " << mSendBuffer->size() << " BYTE " << endl;
-  //  char *p=mSendBuffer->data();
-  //  for (int i=0;i<16;i++) printf("%02x ",(unsigned char)(*(p+i)));printf("\n");
-  mProcess->writeStdin(mSendBuffer->data(),mSendBuffer->size());
-
-}
-void KMessageProcess::slotWroteStdin(KProcess * )
+void KMessageProcess::slotReceivedStderr()
 {
-  kdDebug(11001) << k_funcinfo << endl;
-  if (mSendBuffer)
+  QByteArray ba;
+  kDebug(11001)<<"@@@ KMessageProcess::slotReceivedStderr";
+
+  mProcess->setReadChannel(QProcess::StandardError);
+  while(mProcess->canReadLine())
   {
-    delete mSendBuffer;
-    mSendBuffer=0;
-  }
-  writeToProcess();
-}
+    ba = mProcess->readLine();
+    if( ba.isEmpty() )
+      return;
+    ba.chop( 1 );   // remove '\n'
 
-void KMessageProcess::slotReceivedStderr(KProcess * proc, char *buffer, int buflen)
-{
-  int pid=0;
-  int len;
-  char *p;
-  char *pos;
-//  kdDebug(11001)<<"############# Got stderr " << buflen << " bytes" << endl;
-
-  if (!buffer || buflen==0) return ; 
-  if (proc) pid=proc->pid();
-
-
-  pos=buffer;
-  do
-  {
-    p=(char *)memchr(pos,'\n',buflen);
-    if (!p) len=buflen;
-    else len=p-pos;
-
-    QByteArray a;
-    a.setRawData(pos,len);
-    QString s(a);
-    kdDebug(11001) << "PID" <<pid<< ":" << s << endl;
-    a.resetRawData(pos,len);
-    if (p) pos=p+1;
-    buflen-=len+1;
-  }while(buflen>0);
+    kDebug(11001) << "KProcess (" << ba.size() << "):" << ba.constData();
+    emit signalReceivedStderr(ba);
+    ba.clear();
+  };
 }
 
 
-void KMessageProcess::slotReceivedStdout(KProcess * , char *buffer, int buflen)
+void KMessageProcess::slotReceivedStdout()
 {
-  kdDebug(11001) << "$$$$$$ " << k_funcinfo << ": Received " << buflen << " bytes over inter process communication" << endl;
+  mProcess->setReadChannel(QProcess::StandardOutput);
+  QByteArray ba = mProcess->readAll();
+  kDebug(11001) << "$$$$$$ " << ": Received" << ba.size() << "bytes over inter process communication";
 
-  // TODO Make a plausibility check on buflen to avoid memory overflow
-  while (mReceiveCount+buflen>=mReceiveBuffer.size()) mReceiveBuffer.resize(mReceiveBuffer.size()+1024);
-  memcpy(mReceiveBuffer.data()+mReceiveCount,buffer,buflen);
-  mReceiveCount+=buflen;
+  // Resize receive buffer
+  while (mReceiveCount+ba.size()>=mReceiveBuffer.size()) mReceiveBuffer.resize(mReceiveBuffer.size()+1024);
+  // was 08/2007: mReceiveBuffer += ba;
+  qCopy(ba.begin(), ba.begin()+ba.size(), mReceiveBuffer.begin()+mReceiveCount);
+  mReceiveCount += ba.size();
 
   // Possbile message
-  while (mReceiveCount>2*sizeof(long))
+  while (mReceiveCount>int(2*sizeof(long)))
   {
     long *p1=(long *)mReceiveBuffer.data();
     long *p2=p1+1;
-    unsigned int len;
+    int len;
     if (*p1!=0x4242aeae)
     {
-      kdDebug(11001) << k_funcinfo << ": Cookie error...transmission failure...serious problem..." << endl;
-//      for (int i=0;i<mReceiveCount;i++) fprintf(stderr,"%02x ",mReceiveBuffer[i]);fprintf(stderr,"\n");
+      kDebug(11001) << ": Cookie error...transmission failure...serious problem...";
     }
     len=(int)(*p2);
-    if (len<2*sizeof(long))
+    if (len<int(2*sizeof(long)))
     {
-      kdDebug(11001) << k_funcinfo << ": Message size error" << endl;
+      kDebug(11001) << ": Message size error";
       break;
     }
     if (len<=mReceiveCount)
     {
-      kdDebug(11001) << k_funcinfo << ": Got message with len " << len << endl;
+      kDebug(11001) << ": Got message with len" << len;
 
-      QByteArray msg;
+      QByteArray msg ;
+      msg.resize(len);
     //  msg.setRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
-      msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
+     
+      qCopy(mReceiveBuffer.begin()+2*sizeof(long),mReceiveBuffer.begin()+len, msg.begin());
+//       msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
       emit received(msg);
      // msg.resetRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
       // Shift buffer
@@ -387,9 +354,9 @@ void KMessageProcess::slotReceivedStdout(KProcess * , char *buffer, int buflen)
   }
 }
 
-void KMessageProcess::slotProcessExited(KProcess * /*p*/)
+void KMessageProcess::slotProcessExited(int exitCode, QProcess::ExitStatus)
 {
-  kdDebug(11001) << "Process exited (slot)" << endl;
+  kDebug(11001) << "Process exited (slot) with code" << exitCode;
   emit connectionBroken();
   delete mProcess;
   mProcess=0;
@@ -397,7 +364,7 @@ void KMessageProcess::slotProcessExited(KProcess * /*p*/)
 
 
 // ----------------------- KMessageFilePipe ---------------------------
-KMessageFilePipe::KMessageFilePipe(QObject *parent,QFile *readfile,QFile *writefile) : KMessageIO(parent,0)
+KMessageFilePipe::KMessageFilePipe(QObject *parent,QFile *readfile,QFile *writefile) : KMessageIO(parent)
 {
   mReadFile=readfile;
   mWriteFile=writefile;
@@ -414,6 +381,7 @@ bool KMessageFilePipe::isConnected () const
   return (mReadFile!=0)&&(mWriteFile!=0);
 }
 
+// Send to parent
 void KMessageFilePipe::send(const QByteArray &msg)
 {
   unsigned int size=msg.size()+2*sizeof(long);
@@ -425,15 +393,18 @@ void KMessageFilePipe::send(const QByteArray &msg)
   *p1=0x4242aeae;
   *p2=size;
   
-  QByteArray buffer;
-  buffer.assign(tmpbuffer,size);
-  mWriteFile->writeBlock(buffer);
+  QByteArray buffer(tmpbuffer,size);
+  mWriteFile->write(buffer);
   mWriteFile->flush();
-  /*
+  delete [] tmpbuffer;
+
+  /* DEBUG:
   fprintf(stderr,"+++ KMessageFilePipe:: SEND(%d to parent) realsize=%d\n",msg.size(),buffer.size());
-  for (int i=0;i<buffer.size();i++) fprintf(stderr,"%02x ",buffer[i]);fprintf(stderr,"\n");
+  for (int i=0;i<buffer.size();i++) fprintf(stderr,"%02x ",(unsigned char)buffer.at(i));fprintf(stderr,"\n");
   fflush(stderr);
   */
+ 
+
 }
 
 void KMessageFilePipe::exec()
@@ -441,22 +412,23 @@ void KMessageFilePipe::exec()
 
   // According to BL: Blocking read is ok
   // while(mReadFile->atEnd()) { usleep(100); }
-
-   int ch=mReadFile->getch();
+   char ch;
+   mReadFile->getChar(&ch);
 
    while (mReceiveCount>=mReceiveBuffer.size()) mReceiveBuffer.resize(mReceiveBuffer.size()+1024);
-   mReceiveBuffer[mReceiveCount]=(char)ch;
+   mReceiveBuffer[mReceiveCount]=ch;
    mReceiveCount++;
 
    // Change for message 
-   if (mReceiveCount>=2*sizeof(long))
+   if (mReceiveCount>=int(2*sizeof(long)))
    {
      long *p1=(long *)mReceiveBuffer.data();
      long *p2=p1+1;
-     unsigned int len;
+     int len;
      if (*p1!=0x4242aeae)
      {
        fprintf(stderr,"KMessageFilePipe::exec:: Cookie error...transmission failure...serious problem...\n");
+       fflush(stderr);
 //       for (int i=0;i<16;i++) fprintf(stderr,"%02x ",mReceiveBuffer[i]);fprintf(stderr,"\n");
      }
      len=(int)(*p2);
@@ -465,8 +437,10 @@ void KMessageFilePipe::exec()
        //fprintf(stderr,"KMessageFilePipe::exec:: Got Message with len %d\n",len);
 
        QByteArray msg;
+       msg.resize(len);
        //msg.setRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
-       msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
+       qCopy(mReceiveBuffer.begin()+2*sizeof(long),mReceiveBuffer.begin()+len, msg.begin());
+// 	msg.duplicate(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
        emit received(msg);
        //msg.resetRawData(mReceiveBuffer.data()+2*sizeof(long),len-2*sizeof(long));
        mReceiveCount=0;
